@@ -48,6 +48,7 @@ from servicecatalog_puppet import asset_helpers
 from servicecatalog_puppet import constants
 
 import traceback
+import botocore
 
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
@@ -490,11 +491,18 @@ def _do_bootstrap(
         z.writestr("parameters.yaml", 'single_account: "000000000000"')
 
     with betterboto_client.ClientContextManager("s3") as s3:
-        s3.put_object(
-            Bucket=f"sc-puppet-parameterised-runs-{puppet_account_id}",
-            Key="parameters.zip",
-            Body=buff.getvalue(),
-        )
+        try:
+            s3.head_object(
+                Bucket=f"sc-puppet-parameterised-runs-{puppet_account_id}",
+                Key="parameters.zip",
+            )
+        except botocore.exceptions.ClientError as ex:
+            if ex.response["Error"]["Code"] == "404":
+                s3.put_object(
+                    Bucket=f"sc-puppet-parameterised-runs-{puppet_account_id}",
+                    Key="parameters.zip",
+                    Body=buff.getvalue(),
+                )
 
     click.echo("Finished creating {}.".format(constants.BOOTSTRAP_STACK_NAME))
     if source_provider == "CodeCommit":
